function pm_DebugLevel_Callback(hObject, eventdata, handles)
% --- Executes on selection change in pm_DebugLevel.
% hObject    handle to pm_DebugLevel (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns pm_DebugLevel contents as cell array
%        contents{get(hObject,'Value')} returns selected item from pm_DebugLevel


    debugMsg( 'calling pm_DebugLevel_Callback()', 2 )






end

